1#ifndef __MATH_DUDXYZ_KERNEL_H__
2#define __MATH_DUDXYZ_KERNEL_H__
46template<
typename T, const
int LX, const
int CHUNKS >
79 while(l < (
LX *
LX *
LX)) {
90 for (
int n = 0; n <
nchunks; n++) {
94 const int k =
jk /
LX;
100 for (
int l = 0; l <
LX; l++) {
114template<
typename T, const
int LX, const
int EB >
133 static_assert(
sizeof(
shu) +
138 "kstep block exceeds the LDS budget");
177 for (
int k = 0;
k <
LX; ++
k) {
182 for (
int l = 0; l <
LX; l++) {
190 for (
int l = 0; l <
LX; l++) {
218#if defined(__gfx90a__) || defined(__gfx942__)
220template<
typename T, const
int LX, const
int NWF, const
int TILE >
245 "wavefronts per block must split evenly over the elements");
255 static_assert(
sizeof(
shdx) +
sizeof(
shdy) +
sizeof(
shdz) +
258 "mfma block exceeds the shared memory budget");
262 const int tid = wf * 64 +
lane;
265 const int eb = wf /
WPE;
295 mfma_contract_sel<T, LX, 0, false, false, WPE, TILE, 0, NEL>::run(
298 mfma_contract_sel<T, LX, 1, false, false, WPE, TILE, 0, NEL>::run(
301 mfma_contract_sel<T, LX, 2, false, false, WPE, TILE, 0, NEL>::run(
308 const int gp = p +
ele;
328template<
typename T, const
int LX, const
int NWF, const
int TILE >
331 const T *,
const T *,
const T *,
const T *,
335#if defined(__gfx90a__) || defined(__gfx942__)
338#define NEKO_DUDXYZ_MFMA_DISPATCH(TYPE, LXV) \
339 template< const int NWF, const int TILE > \
340 struct dudxyz_mfma_dispatch< TYPE, LXV, NWF, TILE > { \
341 __device__ static void run(TYPE * du, \
349 const TYPE * jacinv, \
351 dudxyz_mfma_elem< TYPE, LXV, NWF, TILE >(du, u, dr, ds, dt, dx, dy, dz, \
385template<
typename T, const
int LX, const
int NWF, const
int TILE >
398 dudxyz_mfma_dispatch< T, LX, NWF, TILE >::run(du,
u,
dr,
ds,
dt,
dx,
dy,
dz,
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__shared__ T shu[EB *LX *LX]
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dz
__global__ void const T *__restrict__ const T *__restrict__ dr
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dy
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ ds
__shared__ T shdy[LX *LX]
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dt
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dx
__shared__ T shdx[LX *LX]
__shared__ T shdz[LX *LX]
__global__ void dudxyz_kernel_1d(T *__restrict__ du, const T *__restrict__ u, const T *__restrict__ dr, const T *__restrict__ ds, const T *__restrict__ dt, const T *__restrict__ dx, const T *__restrict__ dy, const T *__restrict__ dz, const T *__restrict__ jacinv)
__global__ void const T *__restrict__ u
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const int nelv
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ jacinv
#define NEKO_EB_BOUNDS(NT)
__global__ void __launch_bounds__((LX *LX *EB)) dudxyz_kernel_kstep(T *__restrict__ du
#define NEKO_MFMA_NEL_N(EB, LX, SZ, TILE)
#define NEKO_MFMA_EB_N(NWF, LX, SZ)
static __device__ void run(T *, const T *, const T *, const T *, const T *, const T *, const T *, const T *, const T *, const int)